import time, datetime
import simplejson as sj

from scrapy.spider import BaseSpider
from scrapy.http import Request

from miracas.items import MiracasItem
from miracas.settings import *

class InkFruitSpider(BaseSpider):
    name = 'inkfruit'
    allowed_domains = ['inkfruit.com']

    req_url = 'http://www.inkfruit.com/activity/index/query?qt=1&uf=0&tm='

    '''
    # From JS Code :
        var feedViewHelper={getActionClass:function(action){var actionClassTmpl=[];
        actionClassTmpl[1]='class="scIcons scPrView" title="Viewed this category"';
        actionClassTmpl[2]='class="scIcons scPrView" title="Viewed this product"';
        actionClassTmpl[3]='class="scIcons scPrAdd" title="Added this product"';
        actionClassTmpl[4]='class="scIcons scPrShop" title="Bought this"';
        actionClassTmpl[5]='class="scIcons scPrRate" title="Reviewed this product"';
    '''

    activity_list = [None, "Viewed this category", "Viewed this product", "Added this product", "Bought this", "Reviewed this product"]

    def start_requests(self):
        ts = time.mktime(datetime.datetime.utcnow().timetuple()) - TIME_FREQ*60
        yield Request(self.req_url+str(int(ts)))

    def parse(self, response):
        for e in sj.loads(response.body[18:-3]):
            try:
                item = MiracasItem()
                item['feedactivity_id'] = e['activity_id']
                item['created_at'] = e['created_at']
                if isinstance(e['object_data'], list):
                    od_img = []
                    od_url = []
                    for od in e['object_data']:
                        od_img.append(od['img'])
                        od_url.append(od['url'])
                    item['product_image_url'] = '; '.join(od_img)
                    item['product_url'] = '; '.join(od_url)
                else:
                    item['product_image_url'] = e['object_data']['img']
                    item['product_url'] = e['object_data']['url']

                item['user_email'] = e['user_data'].get('email','')
                item['user_name'] = e['user_data'].get('firstname','') + ' ' + e['user_data'].get('lastname','')
                item['user_fbid'] = e['user_data'].get('fbid','')

                item['user_action'] = self.activity_list[int(e['event_type'])]
                yield item
            except Exception, ex:
                print ex
                pass
